import axios from "axios";
import store from "@/store";
import router from "@/router";
import { Message } from "element-ui";

const apiService = axios.create({
  baseURL: "/api",
  timeout: 5000,
});

//请求拦截器
apiService.interceptors.request.use(
  (config) => {
    if (store.state.user.token !== null) {
      config.headers.token = store.state.user.token;
    }
    return config;
  },
  (error) => {
    console.error("请求错误：", error);
    return Promise.reject(error);
  }
);

//响应拦截器
apiService.interceptors.response.use(
  (success) => {
    if (success.status && success.status === 200) {
      const { code } = success.data;
      if (code === 500 || code === 403 || code === 401 || code === 400) {
        if (code === 401) {
          Message.error("未登录或登录已过期，请重新登录");
          router.replace("/login");
        } else {
          if (success.data.msg) {
            Message.error(success.data.msg);
          }
        }
      } else if (code === 200 && success.data.msg) {
        Message.success(success.data.msg);
      }
    }
    return success.data;
  },
  (error) => {
    const { code } = error.response;
    if (code === 504 || code === 404) {
      Message.error("服务器被吃了⊙﹏⊙∥");
    } else if (code === 403) {
      Message.error("权限不足,请联系管理员");
    } else if (code === 401) {
      Message.error("未登录或登录已过期，请重新登录");
      router.replace("/login");
    } else {
      if (error.response.data.msg) {
        Message.error(error.response.data.msg);
      } else {
        Message.error("未知错误");
      }
    }
  }
);

export default apiService;
